package com.yunzhi.drawlots.controller;

import com.yunzhi.drawlots.common.BaseController;
import com.yunzhi.drawlots.common.JWTUtils;
import com.yunzhi.drawlots.common.ResponseBean;
import com.yunzhi.drawlots.common.StringUtils;
import com.yunzhi.drawlots.entity.TaPerson;
import com.yunzhi.drawlots.service.ITaPersonService;
import com.yunzhi.drawlots.vo.LoginParam;
import com.yunzhi.drawlots.vo.MPLogin;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.util.DigestUtils;
import org.springframework.web.bind.annotation.*;

import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.Map;

@Api(tags = "登入/登出")
@RestController
public class LoginController extends BaseController {

    @Value("${biz.admin.account}")
    String adminAccount;

    @Value("${biz.admin.password}")
    String adminPassword;

    @Autowired
    ITaPersonService iTaPersonService;

    @PostMapping("/admin/login")
    @ApiOperation(value="后端登录", notes = "后端登录", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean login(@ApiParam("登录参数") @RequestBody LoginParam loginParam) throws Exception {
        if (null == loginParam) {
            return ResponseBean.error("账户或密码不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        String userName = loginParam.getUserName();
        String password = loginParam.getPassword();

        if (StringUtils.isEmpty(userName) || StringUtils.isEmpty(password)) {
            return ResponseBean.error("账户或密码不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (!adminAccount.equals(userName)) {
            return ResponseBean.error("账户或密码不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        String targetPassword = md5(md5(adminPassword) + adminAccount);

        if (!checkPassword(password, targetPassword, adminAccount)) {
            return ResponseBean.error("账户或密码不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        // 生成 token
        Map<String, Object> tokenMap = new HashMap<String, Object>() {{
           put("userId", adminAccount);
        }};
        String token = JWTUtils.encode(tokenMap);

        Map<String, Object> res = new HashMap<String, Object>() {{
//            put("user", sysUser);
            put("token", token);
        }};
        return ResponseBean.success(res);
    }

    /**
     * 根据id查询对象
     * @param params  登录参数
     */
    @RequestMapping(value="/wx/login",method= RequestMethod.POST)
    @ApiOperation(value="微信登录", notes = "微信登录", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taPersonGet(@ApiParam("对象ID") @RequestBody MPLogin params) throws Exception{
        String openid = params.getOpenid();
        if (StringUtils.isEmpty(openid)) {
            return ResponseBean.error("登录参数不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaPerson taPerson = iTaPersonService.getByOpenId(openid);

        // 更新人员信息
        if (!StringUtils.isEmpty(params.getNickname())) {
            taPerson.setName(params.getNickname());
            taPerson.setAvatar(params.getHeadImgUrl());
            iTaPersonService.updateById(taPerson);
        }

        // 生成 token
        Map<String, Object> tokenMap = new HashMap<String, Object>() {{
            put("userId", taPerson.getPersonId());
        }};
        String token = JWTUtils.encode(tokenMap);

        Map<String, Object> res = new HashMap<String, Object>() {{
            put("user", taPerson);
            put("token", token);
        }};

        return ResponseBean.success(res);
    }

    private boolean checkPassword(String src, String targ, String salt) {
        return md5((src+salt)).equals(targ);
    }

    private String md5(String src) {
        return DigestUtils.md5DigestAsHex(src.getBytes(StandardCharsets.UTF_8));
    }
}
