package com.yunzhi.drawlots.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.drawlots.common.*;
import com.yunzhi.drawlots.service.ITaPrizeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.drawlots.service.ITaPersonService;
import com.yunzhi.drawlots.entity.TaPerson;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
    * 用户表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-01-13
 */

@Api(tags = "用户表")
@RestController
@RequestMapping("/")
public class TaPersonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPersonController.class);

    @Autowired
    public ITaPersonService iTaPersonService;

    @Autowired
    public ITaPrizeService iTaPrizeService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taPerson",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPersonList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                     @ApiParam(value = "开始时间", example = "2021-01-01") @RequestParam(value ="startDate", required = false) String startDate,
                                     @ApiParam(value = "结束时间", example = "2021-10-31") @RequestParam(value ="endDate", required = false) String endDate) throws Exception{

        LocalDateTime start = null, end = null;

        if (!StringUtils.isEmpty(startDate)) {
            start = DateUtils.from(startDate + " 00:00:00", "yyyy-MM-dd HH:mm:ss");
        }
        if (!StringUtils.isEmpty(endDate)) {
            end = DateUtils.from(endDate + " 23:59:59", "yyyy-MM-dd HH:mm:ss");
        }

        IPage<TaPerson> pg = new Page<>(pageNum, pageSize);
        IPage<TaPerson> result = iTaPersonService.getPageBy(pg, start, end);
        return ResponseBean.success(result);
    }

    @RequestMapping(value="/taPerson",method= RequestMethod.POST)
    @ApiOperation(value="导出Excel", notes = "导出Excel", httpMethod = "POST", response = ResponseBean.class)
    public void exportXls(@ApiParam(value = "开始时间", example = "2021-01-01") @RequestParam(value ="startDate", required = false) String startDate,
                          @ApiParam(value = "结束时间", example = "2021-10-31") @RequestParam(value ="endDate", required = false) String endDate,
                          HttpServletResponse response) throws Exception {
        LocalDateTime start = null, end = null;

        if (!StringUtils.isEmpty(startDate)) {
            start = DateUtils.from(startDate + " 00:00:00", "yyyy-MM-dd HH:mm:ss");
        }
        if (!StringUtils.isEmpty(endDate)) {
            end = DateUtils.from(endDate + " 23:59:59", "yyyy-MM-dd HH:mm:ss");
        }

        List<TaPerson> result = iTaPersonService.getListBy(start, end);
        ExcelUtils.flush(response, TaPerson.class, result, "参与人员名单");
    }

//    /**
//     * 保存对象
//     * @param taPerson 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taPerson",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean taPersonAdd(@ApiParam("保存内容") @RequestBody TaPerson taPerson) throws Exception{
//
//        if (iTaPersonService.save(taPerson)){
//            return ResponseBean.success(taPerson);
//        }else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taPerson/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taPersonDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
//        if(iTaPersonService.removeById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taPerson 实体对象
//     * @return
//     */
//    @RequestMapping(value="/wx/taPerson/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taPersonUpdate(@ApiParam("对象ID") @PathVariable String id,
//                                        @ApiParam("更新内容") @RequestBody TaPerson taPerson) throws Exception{
//
//        TaPerson origin = iTaPersonService.getByPhone(taPerson.getPhone());
//        if (null != origin && !id.equals(origin.getPersonId())) {
//            return ResponseBean.error("手机号已存在, 请重新填写", ResponseBean.ERROR_UNAVAILABLE);
//        }
//
//        origin = iTaPersonService.getById(id);
//        if (null == origin) {
//            return ResponseBean.error("人员信息校验失败, 请刷新重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//
//        taPerson.setPersonId(id);
//
//        if (iTaPersonService.updateName(taPerson)){
//            return ResponseBean.success(iTaPersonService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }


    /**
     * 抽奖
     * @param id  实体ID
     */
    @RequestMapping(value="/wx/taPerson/{id}/prize",method= RequestMethod.GET)
    @ApiOperation(value="抽奖", notes = "抽奖", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getPrize(@ApiParam("人员ID") @PathVariable String id) throws Exception{
        TaPerson taPerson = iTaPersonService.getById(id);

        if (taPerson.getIsJoined() || taPerson.getIsWinning()) {
            return ResponseBean.error("您已参与抽奖!", ResponseBean.ERROR_UNAVAILABLE);
        }

        try {
            iTaPrizeService.drawLottery(taPerson);
        } catch (Exception e) {
            if (e.getMessage().equals("no-prize")) {
                return ResponseBean.error("奖品已抽完", 9999);
            }

            throw e;
        }

        return ResponseBean.success(taPerson);
    }
}
