package com.yunzhi.drawlots.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.drawlots.common.BaseController;
import com.yunzhi.drawlots.common.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.drawlots.service.ITaPrizeService;
import com.yunzhi.drawlots.entity.TaPrize;

import java.util.List;

/**
 * <p>
    * 奖品表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-01-13
 */

@Api(tags = "奖品表")
@RestController
@RequestMapping("/")
public class TaPrizeController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPrizeController.class);

    @Autowired
    public ITaPrizeService iTaPrizeService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taPrize",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPrizeList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

        IPage<TaPrize> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaPrize> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByAsc("sort_no");

        IPage<TaPrize> result = iTaPrizeService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }


    /**
     * 获取奖品列表
     * @return
     */
    @RequestMapping(value="/wx/taPrize",method= RequestMethod.GET)
    @ApiOperation(value="获取奖品列表", notes = "获取奖品列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getPrizeList() throws Exception{

        QueryWrapper<TaPrize> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByAsc("sort_no");

        List<TaPrize> result = iTaPrizeService.list(queryWrapper);
        return ResponseBean.success(result);
    }

//    /**
//     * 保存对象
//     * @param taPrize 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taPrize",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean taPrizeAdd(@ApiParam("保存内容") @RequestBody TaPrize taPrize) throws Exception{
//
//        if (iTaPrizeService.save(taPrize)){
//            return ResponseBean.success(taPrize);
//        } else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taPrize/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taPrizeDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaPrizeService.removeById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taPrize 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taPrize/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taPrizeUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaPrize taPrize) throws Exception{
//
//        if (iTaPrizeService.updateById(taPrize)){
//            return ResponseBean.success(iTaPrizeService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taPrize/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taPrizeGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaPrizeService.getById(id));
//    }
}
