package com.yunzhi.drawlots.service.impl;

import com.yunzhi.drawlots.common.MathUtils;
import com.yunzhi.drawlots.entity.TaPerson;
import com.yunzhi.drawlots.entity.TaPrize;
import com.yunzhi.drawlots.mapper.TaPersonMapper;
import com.yunzhi.drawlots.mapper.TaPrizeMapper;
import com.yunzhi.drawlots.service.ITaPrizeService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;

/**
 * <p>
 * 奖品表 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2022-01-13
 */
@Service
public class TaPrizeServiceImpl extends ServiceImpl<TaPrizeMapper, TaPrize> implements ITaPrizeService {

    private Lock lock = new ReentrantLock();

    @Autowired
    public TaPersonMapper taPersonMapper;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void drawLottery(TaPerson taPerson) throws Exception {
        // 100ms 内拿不到锁就超时
        if (lock.tryLock(100, TimeUnit.MILLISECONDS)) {
            try {
                List<TaPrize> taPrizeList = baseMapper.getStock();
                if (null == taPrizeList || taPrizeList.size() < 1) {
                    throw new Exception("no-prize");
                }

                LocalDateTime now = LocalDateTime.now();
                taPerson.setIsJoined(true);
                taPerson.setJoinedDate(now);

                // 构造奖池
                List<String> pools = new ArrayList<>();
                for (TaPrize prize : taPrizeList) {
                    String prizeId = prize.getPrizeId();
                    for (int i = 0; i < prize.getRate(); i++) {
                        pools.add(prizeId);
                    }
                }

                // 获取随机数
                Integer index = MathUtils.getRand(0, pools.size());
                // 中奖
                String bingoId = pools.get(index);

                // 礼品池减一
                Optional<TaPrize> bingoPrize = taPrizeList.stream().filter(x -> x.getPrizeId().equals(bingoId)).findFirst();
                int row = baseMapper.reduceStock(bingoId, bingoPrize.get().getExitsNum());
                if (row != 1) {
                    throw new Exception("抽奖失败, 请重试");
                }

                // 更新抽奖明细
                taPerson.setIsWinning(true);
                taPerson.setPrizeId(bingoId);
                taPerson.setPrizeDate(now);
                row = taPersonMapper.updateById(taPerson);
                if (row != 1) {
                    throw new Exception("设置抽奖明细, 请重试");
                }
            } catch (Exception e) {
                throw e;
            } finally {
                lock.unlock();
            }
        } else {
            throw new Exception("抽奖人数太多, 请稍后重试");
        }
    }
}
